@@ -1,4 +1,5 @@
 import pytest
+import copy
 
 def test_modelsim():
     import os
@@ -10,13 +11,14 @@ def test_modelsim():
     name         = 'test_modelsim_0'
     tool         = 'modelsim'
     tool_options = {
+        'vcom_options' : ['various', 'vcom_options'],
         'vlog_options' : ['some', 'vlog_options'],
         'vsim_options' : ['a', 'few', 'vsim_options'],
     }
 
     #FIXME: Add VPI tests
-    (backend, args, work_root) = setup_backend(paramtypes, name, tool, tool_options, use_vpi=False)
-    backend.configure(args)
+    (backend, work_root) = setup_backend(paramtypes, name, tool, tool_options, use_vpi=False)
+    backend.configure()
 
     compare_files(ref_dir, work_root, [
         'Makefile',
@@ -24,7 +26,7 @@ def test_modelsim():
         'edalize_main.tcl',
     ])
 
-    orig_env = os.environ.copy()
+    orig_env = copy.deepcopy(os.environ)
     os.environ['MODEL_TECH'] = os.path.join(tests_dir, 'mock_commands')
 
     backend.build()
@@ -32,7 +34,7 @@ def test_modelsim():
 
     compare_files(ref_dir, work_root, ['vsim.cmd'])
 
-    backend.run(args)
+    backend.run()
 
     with open(os.path.join(ref_dir, 'vsim2.cmd')) as fref, open(os.path.join(work_root, 'vsim.cmd')) as fgen:
         assert fref.read() == fgen.read()
